@@ -1,5 +1,5 @@
 /*
- * $Id: file.c,v 1.92.2.2.2.31.2.23 2008/12/23 09:39:02 didg Exp $
+ * $Id: file.c,v 1.92.2.2.2.31.2.24 2009/07/20 18:29:56 didg Exp $
  *
  * Copyright (c) 1990,1993 Regents of The University of Michigan.
  * All Rights Reserved.  See COPYRIGHT.
@@ -595,7 +595,6 @@ int	ibuflen _U_, *rbuflen;
     char		*path, *upath;
     int			creatf, did, openf, retvalue = AFP_OK;
     u_int16_t		vid;
-    int                 ret;
     struct path		*s_path;
     
 #ifdef DEBUG
@@ -632,8 +631,6 @@ int	ibuflen _U_, *rbuflen;
     }
 
     upath = s_path->u_name;
-    if (0 != (ret = check_name(vol, upath))) 
-       return  ret;
     
     /* if upath is deleted we already in trouble anyway */
     if ((of = of_findname(s_path))) {
