@@ -1,5 +1,5 @@
 /*
- * $Id: filedir.c,v 1.45.2.2.2.14.2.6 2009/01/28 05:37:58 didg Exp $
+ * $Id: filedir.c,v 1.45.2.2.2.14.2.7 2009/09/01 12:34:38 franklahm Exp $
  *
  * Copyright (c) 1990,1993 Regents of The University of Michigan.
  * All Rights Reserved.  See COPYRIGHT.
@@ -313,8 +313,10 @@ int check_name(const struct vol *vol, char *name)
     if ((vol->v_flags & AFPVOL_NOHEX) && strchr(name, '/'))
         return AFPERR_PARAM;
 
-    if (!vol->validupath(vol, name))
+    if (!vol->validupath(vol, name)) {
+        LOG(log_info, logtype_afpd, "check_name: illegal name: '%s'", name);
         return AFPERR_EXIST;
+    }
 
     /* check for vetoed filenames */
     if (veto_file(vol->v_veto, name))
@@ -775,15 +777,13 @@ int veto_file(const char*veto_str, const char*path)
 
     if ((veto_str == NULL) || (path == NULL))
         return 0;
-    /*
-    #ifdef DEBUG
-    	LOG(log_debug, logtype_afpd, "veto_file \"%s\", \"%s\"", veto_str, path);
-    #endif
-    */
+
     for(i=0, j=0; veto_str[i] != '\0'; i++) {
         if (veto_str[i] == '/') {
-            if ((j>0) && (path[j] == '\0'))
+            if ((j>0) && (path[j] == '\0')) {
+                LOG(log_info, logtype_afpd, "vetoed file:'%s'", path);
                 return 1;
+            }
             j = 0;
         } else {
             if (veto_str[i] != path[j]) {
